==> haskell-data-serializer-0.3.5-336.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-serializer
version:              0.3.5
visibility:           public
id:                   data-serializer-0.3.5-LCo3k9EPCpDUjqxiSHpwP
key:                  data-serializer-0.3.5-LCo3k9EPCpDUjqxiSHpwP
license:              BSD-3-Clause
copyright:            2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-serializer
synopsis:             Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.

category:             Data
abi:                  9b9d271b3e53028fffe68fa60f879fb4
exposed:              True
exposed-modules:      Data.Deserializer Data.Serializer
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-serializer-0.3.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-serializer-0.3.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-serializer-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-serializer
hs-libraries:         HSdata-serializer-0.3.5-LCo3k9EPCpDUjqxiSHpwP
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    data-endian-0.1.1-AArotBb6YVx66xbeUMCKUi
    parsers-0.12.12-1ZzbvPY4A605Mj7Pb7vKRT
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8

haddock-interfaces:
    /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock

haddock-html:         /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3.5-337-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-serializer
version:              0.3.5
visibility:           public
id:                   data-serializer-0.3.5-5CABA8JdaLPGBow7GqzVt9
key:                  data-serializer-0.3.5-5CABA8JdaLPGBow7GqzVt9
license:              BSD-3-Clause
copyright:            2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-serializer
synopsis:             Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.

category:             Data
abi:                  6f0ef5ea74de3fa4e2ebc84d2cf49760
exposed:              True
exposed-modules:      Data.Deserializer Data.Serializer
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-serializer-0.3.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-serializer-0.3.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-serializer-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-serializer
hs-libraries:         HSdata-serializer-0.3.5-5CABA8JdaLPGBow7GqzVt9
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    data-endian-0.1.1-AArotBb6YVx66xbeUMCKUi
    parsers-0.12.12-PO1r5WusBRCqoNlSszPjk
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8

haddock-interfaces:
    /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock

haddock-html:         /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
